/*
 *  src/Engine/Globals.cs
 *  Copyright (C) 2007 Marcin Krystian Krzywonos
 *  License: GNU/GPL version 2
 */


using System;
using Gtk;
using Mono.Unix;
using Incollector.GUI;
using Incollector.GUI.Widgets;


namespace Incollector.Engine {
	
	/// <summary>Global objects and functions</summary>
	public static class Globals {
	
		public static MainWindow MainWindowObject {
			get { return mainWindowObject; }
		}
		
		public static EntriesList Entries {
			get { return mainWindowObject.Entries; }
		}
		
		public static TagsList Tags {
			get { return mainWindowObject.Tags; }
		}
		
		public static bool Inited {
			get { return init; }
		}
		
		
		private static MainWindow  mainWindowObject;
		private static bool        init = false;
		
		
		public static void Init (string[] args)
		{
			mainWindowObject = new MainWindow ();
			
			
			// Import data ?
			if (args.Length > 0) {
				if (System.IO.Path.GetExtension (args [1]) != ".ied") {
					MessageDialog msg = new MessageDialog (Globals.MainWindowObject.window,
						DialogFlags.DestroyWithParent, MessageType.Error, ButtonsType.Ok,
						Catalog.GetString ("The file has an invalid extension."));
					msg.Run ();
					msg.Destroy ();
				} else
					Globals.MainWindowObject.on_import_entries_activate (args, null);
			}
			

			// PLUGINS
			mainWindowObject.ShowWindowMessage (Catalog.GetString ("Please wait"), Catalog.GetString ("Loading plugins"));
			Tools.Repaint ();
			
			// removing plugins which were selected to remove
			System.Collections.ArrayList list = Engine.Settings.GetList ("PluginsToRemove");
			foreach (string pgpath in list)
				Plugins.Plugins.UninstallPlugin (pgpath);
			Engine.Settings.Set ("PluginsToRemove", "");
			
			// loading plugins
			Plugins.Plugins.LoadAllPlugins ();
			
			mainWindowObject.HideWindowMessage ();
			
			init = true;
		}
	}
}
